@@ -6,24 +6,24 @@ $EM_CONF[$_EXTKEY] = [
     'category' => 'templates',
     'constraints' => [
         'depends' => [
-            'typo3' => '9.5.0-9.5.99',
-            'fluid_styled_content' => '9.5.0-9.5.99',
-            'rte_ckeditor' => '9.5.0-9.5.99'
+            'typo3' => '10.4.0-10.4.99',
+            'fluid_styled_content' => '10.4.0-10.4.99',
+            'rte_ckeditor' => '10.4.0-10.4.99'
         ],
         'conflicts' => [
         ],
     ],
     'autoload' => [
         'psr-4' => [
-            'SG\\Sitepackage\\' => 'Classes'
+            'SG\\SgSitepackage\\' => 'Classes'
         ],
     ],
-    'state' => 'stable',
-    'version' => '0.16.0',
+    'state' => 'beta',
+    'version' => '10.1.0',
     'author' => 'Daniel Hoffmann, Marc Saleiko',
     'author_email' => 'hoffmann@smply.gd, saleiko@smply.gd',
     'author_company' => 'Smply.gd GmbH',
     'uploadfolder' => 0,
-    'createDirs' => 'fileadmin/user_upload/forms',
+    'createDirs' => 'fileadmin/user_upload/forms,fileadmin/avatars',
     'clearCacheOnLoad' => 1,
 ];
